FixtureEmpty class

A collection was found, but it holds no documents to choose from.

Inheritance

Constructors

FixtureEmpty()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Why the request was not served.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited