FixtureEmpty class
A collection was found, but it holds no documents to choose from.
- Inheritance
-
- Object
- FixtureOutcome
- FixtureMiss
- FixtureEmpty
Constructors
- FixtureEmpty()
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited